'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-d337cd8a.js');
const helpers = require('./helpers-931fd72e.js');

const icInputLabelCss = "ic-input-label{margin-bottom:var(--ic-space-xs);--ic-typography-color:var(\n    --ic-input-label-text-color,\n    var(--ic-color-text-primary)\n  )}ic-input-label.with-helper{margin-bottom:var(--ic-space-xxxs)}ic-input-label.ic-input-label-readonly{--ic-typography-color:var(--ic-input-label-readonly-typography-color)}ic-input-label .helpertext,ic-input-label .helpertext ::slotted(*){margin-top:var(--ic-space-xxxs);padding-bottom:var(--ic-input-label-helpertext-padding, 0);--ic-typography-color:var(\n    --ic-input-label-helper-text-color,\n    var(--ic-color-text-secondary)\n  )}ic-input-label .helpertext-normal{--ic-typography-color:var(\n    --ic-input-label-helper-text-color,\n    var(--ic-color-text-secondary)\n  )}ic-input-label .helpertext-readonly{--ic-typography-color:var(--ic-input-label-readonly-helpertext-color)}ic-input-label .readonly-label{--ic-typography-color:var(--ic-input-label-readonly-label-color)}ic-input-label .error-label{--ic-typography-color:var(--ic-input-label-error-label-color)}";
const IcInputLabelStyle0 = icInputLabelCss;

const InputLabel = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /**
         * If `true`, the disabled state will be set.
         */
        this.disabled = false;
        /**
         * The helper text that will be displayed.
         */
        this.helperText = "";
        /**
         * The label will be visually hidden.
         */
        this.hideLabel = false;
        /**
         * If `true`, the readonly state will be set.
         */
        this.readonly = false;
        /**
         * If `true`, the input label will require a value.
         */
        this.required = false;
        /**
         * The status of the label - e.g. 'error'.
         */
        this.status = "";
        /**
         * @internal If `true`, wraps label text in label tag
         */
        this.useLabelTag = true;
        this.isHelperTextSlotUsed = (slot) => {
            const assignedEls = slot === null || slot === void 0 ? void 0 : slot.assignedElements();
            if (assignedEls && assignedEls.length) {
                for (const el of assignedEls) {
                    if (el.tagName === "SLOT") {
                        // Recursion needed for when slot is forwarded multiple times - through child components
                        // (e.g. in date picker)
                        if (this.isHelperTextSlotUsed(el)) {
                            return true;
                        }
                    }
                    else {
                        // Found an assigned element which is not a nested <slot>
                        return true;
                    }
                }
            }
            return false;
        };
    }
    componentDidLoad() {
        helpers.onComponentRequiredPropUndefined([{ prop: this.label, propName: "label" }], "Input Label");
    }
    render() {
        const { disabled, readonly, label, required, helperText, status, hideLabel, useLabelTag, } = this;
        const labelText = required ? label + " *" : label;
        const helperTextId = this.for && helpers.getInputHelperTextID(this.for);
        const helperTextClass = {
            helpertext: true,
            "helpertext-normal": !disabled && !readonly,
            "helpertext-readonly": readonly,
        };
        const helperTextSlot = this.el.querySelector("slot[name='helper-text']");
        return (index.h(index.Host, { key: 'f03d8032ac769d4ecea37fe7a60e9d5acea54cd9', class: {
                "ic-input-label-disabled": !!disabled,
                "ic-input-label-readonly": readonly,
                "with-helper": this.isHelperTextSlotUsed(helperTextSlot) || helperText !== "",
            } }, !hideLabel && (index.h("ic-typography", { key: '7af61c1f2a1b9068fb9a9b649f60da1784207aa3', variant: "label", class: {
                "readonly-label": readonly,
                "error-label": status === "error" && !(readonly || disabled),
            } }, readonly || !useLabelTag ? (`${labelText}`) : (index.h("label", { htmlFor: this.for }, labelText)))), this.isHelperTextSlotUsed(helperTextSlot) ? (index.h("span", { id: helperTextId, class: helperTextClass }, index.h("slot", { name: "helper-text" }))) : (helperText !== "" && (index.h("ic-typography", { variant: "caption", class: helperTextClass }, index.h("span", { id: helperTextId }, helperText))))));
    }
    get el() { return index.getElement(this); }
};
InputLabel.style = IcInputLabelStyle0;

const icInputValidationCss = "ic-input-validation{width:var(--input-width, 20rem);margin-top:var(--ic-space-xs);display:flex}ic-input-validation.ic-input-validation-full-width{width:100%}ic-input-validation span.status-icon{padding-right:var(--ic-space-xxs)}ic-input-validation span.status-icon>svg{height:1.25rem;width:1.25rem}ic-input-validation span.icon-success>svg{fill:var(--ic-input-validation-success-icon-color)}ic-input-validation span.icon-error>svg{fill:var(--ic-input-validation-error, var(--ic-atoms-status-icon-error))}ic-input-validation span.icon-warning>svg{fill:var(--ic-input-validation-warning-icon-color)}ic-input-validation .statustext{flex-grow:1;color:var(\n    --ic-input-validation-status-text-color,\n    var(--ic-color-text-primary)\n  );--ic-typography-color:var(\n    --ic-input-validation-status-text-color,\n    var(--ic-color-text-primary)\n  )}";
const IcInputValidationStyle0 = icInputValidationCss;

const icon = {
    [helpers.IcInformationStatus.Warning]: helpers.warningIcon,
    [helpers.IcInformationStatus.Error]: helpers.errorIcon,
    [helpers.IcInformationStatus.Success]: helpers.successIcon,
};
const InputValidation = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        /**
         *  The ARIA live mode to apply to the message.
         */
        this.ariaLiveMode = "polite";
        /**
         *  If `true`, the input validation will fill the width of the container.
         */
        this.fullWidth = false;
        /**
         * The status of the validation - e.g. 'error' | 'warning' | 'success'.
         */
        this.status = "";
    }
    componentDidLoad() {
        helpers.onComponentRequiredPropUndefined([{ prop: this.message, propName: "message" }], "Input Validation");
    }
    render() {
        const { ariaLiveMode, fullWidth, status, message } = this;
        const displayIcon = status !== "" ? icon[status] : "";
        return (index.h(index.Host, { key: '2ab746f75a46252bc0755dfd28220dbe555b93b3', class: {
                [`ic-input-validation-${status}`]: status !== "",
                "ic-input-validation-full-width": !!fullWidth,
            } }, displayIcon !== "" && (index.h("span", { key: 'fc02067a0c0f1e9672e190f1bd30774cd2cfcfe0', class: {
                "status-icon": true,
                [`icon-${status}`]: true,
            }, innerHTML: displayIcon })), index.h("ic-typography", { key: 'f8d3c1d9d7f30e232ebbc827033ad318485f7c98', variant: "caption", class: "statustext" }, index.h("span", { key: '73b35c4a5c4dbe77fe4c71032020a0346e34fcfd', "aria-live": ariaLiveMode, id: this.for && helpers.getInputValidationTextID(this.for) }, message)), index.h("slot", { key: '629f37113c9354db274019eadc9ae7140adf921a', name: "validation-message-adornment" })));
    }
    get el() { return index.getElement(this); }
};
InputValidation.style = IcInputValidationStyle0;

exports.ic_input_label = InputLabel;
exports.ic_input_validation = InputValidation;

//# sourceMappingURL=ic-input-label_2.cjs.entry.js.map