import { Host, h } from "@stencil/core";
import checkIcon from "../../assets/check-icon.svg";
import warningIcon from "../../assets/warning-icon-outline.svg";
import { isPropDefined } from "../../utils/helpers";
export class Step {
    constructor() {
        /**
         * @internal If `true`, and a compact stepper  is being used, the current step will be the only step in view.
         */
        this.current = false;
        /**
         * @internal Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
         */
        this.theme = "inherit";
        /**
         * The state of the step within the stepper.
         */
        this.type = "active";
    }
    typeChangeHandler() {
        if (this.variant === "compact" && this.type === "current") {
            this.current = true;
        }
        else {
            this.current = false;
        }
    }
    render() {
        var _a, _b;
        // ARIA LABEL
        let ariaLabel = "";
        if (this.type === "completed") {
            ariaLabel = ". Completed step";
        }
        else if (this.type === "disabled") {
            ariaLabel = ". Non-required step";
        }
        else if (this.status === "required") {
            ariaLabel = ". Required step";
        }
        else if (this.status === "optional") {
            ariaLabel = ". Optional step";
        }
        // STEP STATUS
        let stepStatus;
        if (this.status && isPropDefined(this.status)) {
            stepStatus = this.status[0].toUpperCase() + this.status.slice(1);
        }
        // STEP TYPE
        let stepType;
        if (this.type === "disabled" || this.compactStepStyling === "disabled") {
            stepType = "Not required";
        }
        else if (this.compactStepStyling === "completed") {
            stepType = "Completed";
        }
        // STATUS ICON FOR COMPACT STEP
        let statusIcon;
        if (this.type === "completed" || this.compactStepStyling === "completed") {
            statusIcon = (h("span", { key: 'da8e370996e92dde0f17f6460ecb0c11d8def086', class: "check-icon step-icon", "aria-hidden": "true", innerHTML: checkIcon }));
        }
        else if (this.type === "disabled" ||
            this.compactStepStyling === "disabled") {
            statusIcon = (h("span", { key: '581de517797d73b13bab42503a084a579c540d5f', class: "warning-icon step-icon", "aria-hidden": "true", innerHTML: warningIcon }));
        }
        // COMPACT STEP COMPONENT
        const compactStep = (h("div", { key: '2b0b01b29c81bd1ae351b56f04c18f7eab1ca4f1', class: {
                ["step"]: true,
                ["current"]: !!this.current,
                [`compact-step-${this.compactStepStyling}`]: !!this.compactStepStyling,
                ["disabled"]: this.type === "disabled" || this.compactStepStyling === "disabled",
            } }, h("ic-loading-indicator", { key: '4f2234e8dc571338c71f63263d2cd45460920717', class: {
                "compact-step-progress-indicator": true,
                "not-required": this.type === "disabled" ||
                    this.compactStepStyling === "disabled",
            }, "aria-hidden": "true", size: "small", "inner-label": this.stepNum, progress: this.progress }), h("div", { key: 'bb3834decc5d6e971b8da1b225987f41d7542b67', class: "heading-area" }, h("ic-typography", { key: 'c9ac23c26ecb3a002f065583c36b105dd7a80d35', variant: "h4", class: "heading" }, this.heading), h("div", { key: '72a46d0b49c4b09db01fd6a7a4000efb4d4f6da9', class: "info-line" }, h("ic-typography", { key: '0a8f7b16a04431260d1650474ea86faa0248af2d', variant: "caption", class: "step-num" }, `${this.stepNum} of ${this.lastStepNum}`, h("span", { key: '497ad4a0febb2b9f5380a0bb28f0effc6368cf1d', class: "visually-hidden" }, " steps")), (this.subheading ||
            this.type === "completed" ||
            this.type === "disabled" ||
            (this.variant === "compact" &&
                !!this.compactStepStyling &&
                this.compactStepStyling !== "active") ||
            !!this.status) && (h("div", { key: 'ee5da9d5d75229d3bffbc761dfc4c779b22b063d', class: "step-status" }, statusIcon !== undefined && statusIcon, (this.subheading || stepType) && (h("ic-typography", { key: 'b249e660a2eff61dc1d537ab14e2bf027c2ffab2', variant: "caption" }, this.subheading !== null && isPropDefined(this.subheading)
            ? this.subheading
            : this.type === "disabled" ||
                (this.variant === "compact" &&
                    this.compactStepStyling === "disabled") ||
                this.type === "completed" ||
                (this.variant === "compact" &&
                    this.compactStepStyling === "completed")
                ? stepType
                : this.status && stepStatus))))), this.lastStep ? (h("ic-typography", { variant: "subtitle-small", class: "next-step" }, "Last step")) : (isPropDefined(this.nextStepHeading) && (h("ic-typography", { variant: "subtitle-small", class: "next-step" }, "Next", h("span", { class: "visually-hidden" }, " step is"), ":", " ", this.nextStepHeading))))));
        // ICON FOR DEFAULT STEP
        let icon;
        if (this.type !== "completed") {
            icon = (h("ic-typography", { key: '8d6b60fe3b7cb9426536ac8afaeb798de0291b1c', variant: "subtitle-small" }, h("span", { key: '464e32e9503075944e90e9e42c72ef3955c948d0', class: "step-icon-inner", "aria-hidden": "true" }, this.stepNum)));
        }
        else {
            icon = (h("div", { key: '620c7f67632c073a4e339427bedc5ffed0a4a320', class: "step-icon-inner", "aria-hidden": "true" }, h("span", { key: '1396290202c009168bf4b7983a2af4f5d8fdeb64', class: "check-icon", innerHTML: checkIcon })));
        }
        // STEP CONNECT FOR DEFAULT STEP
        const partialBar = this.type === "current" && (h("div", { key: '7d27dc6a29aca34dcb14c0624c66309614c5378a', class: "step-connect-inner" }));
        const finalStep = !this.lastStep && (h("div", { key: '70aeb7052405a7977a12562c329f227c71e35a8b', class: {
                ["step-connect"]: true,
                ["aligned-full-width"]: !!(((_a = this.el.parentElement) === null || _a === void 0 ? void 0 : _a.classList.contains("ic-stepper-default")) &&
                    !this.el.parentElement.classList.contains("ic-stepper-aligned-left")),
            } }, partialBar));
        // DEFAULT STEP COMPONENT
        const defaultStep = (h("div", { key: '130b7d2d16c416a5e699a20564b475fe0620af18', class: {
                ["step"]: true,
                [`${this.type}`]: true,
            } }, h("div", { key: '6b71087d2f67a0858fdd819424fed8d36084d98e', class: "step-top" }, h("div", { key: 'a9d0fc4317db6cc4b60c8429909fe30dbae3001e', class: "step-icon" }, icon), finalStep), (this.heading || this.subheading || this.status) && (h("div", { key: '13c274e45d81977b4ceeaf98a4e092a2d90fec97', class: "heading-area" }, this.heading && (h("ic-typography", { key: '1c4307d5780fff0c7200631e7b729024e3ca8315', variant: "subtitle-large", class: "heading" }, this.heading)), this.heading && (this.subheading || this.status) && (h("ic-typography", { key: '4e6b789f77f40ed85e486bb8bf25b2209e042a91', variant: "caption", class: "subheading" }, this.subheading !== null && isPropDefined(this.subheading)
            ? this.subheading
            : stepStatus))))));
        return (h(Host, { key: 'aaeb6b423f4a746831b15ec90ae450a4a4c3fc9e', role: "listitem", "aria-label": `Step ${this.stepNum}${ariaLabel}`, "aria-current": (this.current || this.type === "current") && "step", class: {
                ["aligned-full-width"]: !!(((_b = this.el.parentElement) === null || _b === void 0 ? void 0 : _b.classList.contains("ic-stepper-default")) &&
                    !this.el.parentElement.classList.contains("ic-stepper-aligned-left")),
                [`ic-step-${this.variant}`]: true,
                [`ic-theme-${this.theme}`]: this.theme !== "inherit",
            } }, this.variant === "compact" ? compactStep : defaultStep));
    }
    static get is() { return "ic-step"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() {
        return {
            "$": ["ic-step.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["ic-step.css"]
        };
    }
    static get properties() {
        return {
            "compactStepStyling": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcStepTypes",
                    "resolved": "\"active\" | \"completed\" | \"current\" | \"disabled\" | undefined",
                    "references": {
                        "IcStepTypes": {
                            "location": "import",
                            "path": "./ic-step.types",
                            "id": "src/components/ic-step/ic-step.types.ts::IcStepTypes"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "If a compact stepper is being used, this sets the styling of the step."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "compact-step-styling",
                "reflect": false
            },
            "current": {
                "type": "boolean",
                "mutable": true,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "If `true`, and a compact stepper  is being used, the current step will be the only step in view."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "current",
                "reflect": false,
                "defaultValue": "false"
            },
            "lastStep": {
                "type": "boolean",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "If `true`, the step will be marked as being the last one in the series. This is managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "last-step",
                "reflect": false
            },
            "lastStepNum": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The step number of the final step. This is managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "last-step-num",
                "reflect": false
            },
            "nextStepHeading": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The name of the next step. This is managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "next-step-heading",
                "reflect": false
            },
            "progress": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The progress of the next step, calculated by dividing the current step number by the total number of steps. This is managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "progress",
                "reflect": false
            },
            "stepNum": {
                "type": "number",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The step number, managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "step-num",
                "reflect": false
            },
            "status": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcStepStatuses",
                    "resolved": "\"optional\" | \"required\" | undefined",
                    "references": {
                        "IcStepStatuses": {
                            "location": "import",
                            "path": "./ic-step.types",
                            "id": "src/components/ic-step/ic-step.types.ts::IcStepStatuses"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The status of the step. Use this prop to display a status message on the step if it is required or optional."
                },
                "getter": false,
                "setter": false,
                "attribute": "status",
                "reflect": false
            },
            "subheading": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "Additional information about the step. Use this prop to override the default step status messaging displayed when selecting a step type or step status."
                },
                "getter": false,
                "setter": false,
                "attribute": "subheading",
                "reflect": false
            },
            "heading": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string | undefined",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The title of the step within the stepper."
                },
                "getter": false,
                "setter": false,
                "attribute": "heading",
                "reflect": false
            },
            "theme": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcThemeMode",
                    "resolved": "\"dark\" | \"inherit\" | \"light\" | undefined",
                    "references": {
                        "IcThemeMode": {
                            "location": "import",
                            "path": "../../utils/types",
                            "id": "src/utils/types.ts::IcThemeMode"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "Sets the theme color to the dark or light theme color. \"inherit\" will set the color based on the system settings or ic-theme component."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "theme",
                "reflect": false,
                "defaultValue": "\"inherit\""
            },
            "variant": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcStepVariants",
                    "resolved": "\"compact\" | \"default\"",
                    "references": {
                        "IcStepVariants": {
                            "location": "import",
                            "path": "./ic-step.types",
                            "id": "src/components/ic-step/ic-step.types.ts::IcStepVariants"
                        }
                    }
                },
                "required": true,
                "optional": false,
                "docs": {
                    "tags": [{
                            "name": "internal",
                            "text": "The variant of the step. This is managed by ic-stepper."
                        }],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "attribute": "variant",
                "reflect": false
            },
            "type": {
                "type": "string",
                "mutable": false,
                "complexType": {
                    "original": "IcStepTypes",
                    "resolved": "\"active\" | \"completed\" | \"current\" | \"disabled\" | undefined",
                    "references": {
                        "IcStepTypes": {
                            "location": "import",
                            "path": "./ic-step.types",
                            "id": "src/components/ic-step/ic-step.types.ts::IcStepTypes"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": "The state of the step within the stepper."
                },
                "getter": false,
                "setter": false,
                "attribute": "type",
                "reflect": false,
                "defaultValue": "\"active\""
            }
        };
    }
    static get elementRef() { return "el"; }
    static get watchers() {
        return [{
                "propName": "type",
                "methodName": "typeChangeHandler"
            }];
    }
}
//# sourceMappingURL=ic-step.js.map
