import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { i as isSlotUsed, o as onComponentRequiredPropUndefined, f as renderDynamicChildSlots } from './helpers.js';
import { d as defineCustomElement$2 } from './ic-typography2.js';

const icEmptyStateCss = ":host{gap:var(--ic-space-xs);padding:var(--ic-space-xs)}:host,.action-area{display:flex;flex-direction:column}.action-area{gap:var(--ic-space-md)}:host ::slotted(svg),:host ::slotted(img){border-radius:var(--ic-space-xxs)}:host(.ic-empty-state-right),:host(.ic-empty-state-right) .action-area{align-items:flex-end;text-align:right}:host(.ic-empty-state-center),:host(.ic-empty-state-center) .action-area{align-items:center;text-align:center}:host(.image-medium) ::slotted(svg),:host(.image-medium) ::slotted(img){height:calc(3 * var(--ic-space-lg)) !important;width:calc(3 * var(--ic-space-lg)) !important}:host(.image-small) ::slotted(svg),:host(.image-small) ::slotted(img){height:var(--ic-space-xxl) !important;width:var(--ic-space-xxl) !important}:host(.image-large) ::slotted(svg),:host(.image-large) ::slotted(img){height:calc(4 * var(--ic-space-xl)) !important;width:calc(4 * var(--ic-space-xl)) !important}::slotted([slot=\"heading\"]),.empty-state-heading{--ic-typography-color:var(--ic-empty-state-title)}::slotted([slot=\"subheading\"]),.empty-state-subheading{--ic-typography-color:var(--ic-empty-state-subtitle)}::slotted([slot=\"body\"]),.empty-state-body{--ic-typography-color:var(--ic-empty-state-body)}";
const IcEmptyStateStyle0 = icEmptyStateCss;

const EmptyState = /*@__PURE__*/ proxyCustomElement(class EmptyState extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.hostMutationObserver = null;
        /**
         * The alignment of the empty state container.
         */
        this.aligned = "left";
        /**
         * The size of the image or icon used in the image slot.
         */
        this.imageSize = "medium";
        /**
         * Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
         */
        this.theme = "inherit";
    }
    disconnectedCallback() {
        var _a;
        (_a = this.hostMutationObserver) === null || _a === void 0 ? void 0 : _a.disconnect();
    }
    componentDidLoad() {
        !isSlotUsed(this.el, "heading") &&
            onComponentRequiredPropUndefined([{ prop: this.heading, propName: "heading" }], "Empty State");
        this.hostMutationObserver = new MutationObserver((mutationList) => renderDynamicChildSlots(mutationList, ["image", "actions"], this));
        this.hostMutationObserver.observe(this.el, {
            childList: true,
        });
    }
    render() {
        const { aligned, body, maxLines, heading, imageSize, subheading, theme } = this;
        return (h(Host, { key: '1742fa428f2c887fd9b0a200fa5f4040c3ceedf3', class: {
                [`ic-empty-state-${aligned}`]: true,
                [`image-${imageSize}`]: isSlotUsed(this.el, "image"),
                [`ic-theme-${theme}`]: theme !== "inherit",
            } }, isSlotUsed(this.el, "image") && h("slot", { key: '781c3afcd34547dba24bdc777fed7b704d2d27ad', name: "image" }), h("div", { key: 'a8eb38fb47f8e03d3654cc3f26d12ff1369a52ff' }, h("slot", { key: '4375bf33214131da721591bfbea44d03514b9836', name: "heading" }, h("ic-typography", { key: 'd83b8868e417e55a574716e380be3e99ea2f3aa3', variant: "h4", class: "empty-state-heading" }, heading)), h("slot", { key: '79d4fe82562ba2d44ffa5a693a3e9d5743984bbd', name: "subheading" }, h("ic-typography", { key: 'ffd4e8d460b03c3b90b477c0d2f420492a337165', variant: "subtitle-small", class: "empty-state-subheading" }, subheading)), h("slot", { key: '166e1b63631dc5f6a5ada15867fae52442c18e14', name: "body" }, h("ic-typography", { key: 'f63a9ec68fe53dadddd3cb26ffe6478164caf3af', maxLines: maxLines, class: "empty-state-body" }, body))), isSlotUsed(this.el, "actions") && (h("div", { key: 'ccf0fe966f7a2c6f5225005d5bd4266523bf5267', class: "action-area" }, h("slot", { key: 'f9f8f74c450aed47b1e8f0467e290714237251b0', name: "actions" })))));
    }
    get el() { return this; }
    static get style() { return IcEmptyStateStyle0; }
}, [1, "ic-empty-state", {
        "aligned": [1],
        "body": [1],
        "maxLines": [2, "max-lines"],
        "heading": [1],
        "imageSize": [1, "image-size"],
        "subheading": [1],
        "theme": [1]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["ic-empty-state", "ic-typography"];
    components.forEach(tagName => { switch (tagName) {
        case "ic-empty-state":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, EmptyState);
            }
            break;
        case "ic-typography":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}

const IcEmptyState = EmptyState;
const defineCustomElement = defineCustomElement$1;

export { IcEmptyState, defineCustomElement };

//# sourceMappingURL=ic-empty-state.js.map