import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { O as getSlot, P as getSlotContent, i as isSlotUsed } from './helpers.js';
import { d as defineCustomElement$4 } from './ic-button2.js';
import { d as defineCustomElement$3 } from './ic-loading-indicator2.js';
import { d as defineCustomElement$2 } from './ic-tooltip2.js';
import { d as defineCustomElement$1 } from './ic-typography2.js';

const icNavigationMenuCss = ":host{display:block;position:fixed;top:0;left:0;width:100%;min-height:100% !important;background:rgb(0 0 0 / 60%);z-index:var(--ic-z-index-navigation-menu)}.popout-modal{position:absolute;inset:0}.popout-menu{position:fixed;top:0;right:0;width:16rem;bottom:0;background-color:var(--ic-top-navigation-menu-background);color:var(--ic-top-navigation-nav-item);--ic-typography-color:var(--ic-top-navigation-nav-item);box-shadow:var(--ic-elevation-overlay);overflow-y:auto;overflow-x:hidden}:host(.inline) .popout-menu{position:absolute}.menu-close-button-container{position:relative;left:11.875rem;padding:var(--ic-space-md) 0}.nav-group-first{padding-bottom:0}.menu-buttons-container{padding:var(--ic-space-sm) 0;border-bottom:var(--ic-border-width) solid var(--ic-architectural-200)}.menu-buttons-container-nav-item-above{margin-top:var(--ic-space-md);border-top:var(--ic-border-width) solid var(--ic-architectural-200)}.menu-status-version-container{display:flex;flex-wrap:wrap;gap:var(--ic-space-xs);padding:var(--ic-space-md) var(--ic-space-md) var(--ic-space-xl)}.status-version-no-buttons{border-top:var(--ic-space-1px) solid var(--ic-architectural-200)}.menu-status{background-color:var(--ic-status-tag-neutral);--ic-typography-color:var(--ic-color-text-inverted);border-radius:var(--ic-space-md);width:-moz-fit-content;width:fit-content;padding:var(--ic-space-xxs) var(--ic-space-sm)}.menu-version{border-radius:var(--ic-space-md);background-color:var(--ic-status-tag-outlined-background-neutral-contrast);--ic-typography-color:var(--ic-color-text-primary-light);padding:var(--ic-space-xxs) var(--ic-space-sm)}.menu-status-text,.menu-version-text{overflow-wrap:break-word}.navigation-landmark-text{position:absolute;width:var(--ic-space-1px);height:var(--ic-space-1px);padding:0;margin:calc(-1 * var(--ic-space-1px));overflow:hidden}";
const IcNavigationMenuStyle0 = icNavigationMenuCss;

const NAV_GROUP_TAG = "IC-NAVIGATION-GROUP";
const NAV_ITEM_TAG = "IC-NAVIGATION-ITEM";
const NavigationMenu = /*@__PURE__*/ proxyCustomElement(class NavigationMenu extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.icNavigationMenuClose = createEvent(this, "icNavigationMenuClose", 7);
        this.hasButtons = false;
        this.hasNavigation = false;
        this.lastTabStop = null;
        this.navGroupFirst = false;
        this.navItemAboveButtons = false;
        /**
         * The status info to display.
         */
        this.status = "";
        /**
         * Sets the theme color to the dark or light theme color. "inherit" will set the color based on the system settings or ic-theme component.
         */
        this.theme = "inherit";
        /**
         * The version info to display.
         */
        this.version = "";
        this.setLastTabStop = (lastNavGroupExpanded) => {
            let lastEl = this.navigationEls[this.navigationEls.length - 1];
            if (lastEl.tagName === NAV_GROUP_TAG && lastNavGroupExpanded) {
                const childNavItems = lastEl.children;
                lastEl = childNavItems[childNavItems.length - 1];
            }
            if (lastEl.tagName === NAV_ITEM_TAG) {
                //check for slotted content i.e. react router link
                const slotContent = getSlot(lastEl, "navigation-item");
                if (slotContent !== null) {
                    lastEl = slotContent;
                }
            }
            this.lastTabStop = lastEl;
        };
        this.closeMenu = () => {
            this.icNavigationMenuClose.emit();
        };
        this.focusCloseButton = () => {
            var _a;
            (_a = this.closeButton) === null || _a === void 0 ? void 0 : _a.focus();
        };
        this.focusLastTabStop = () => {
            let focusEl;
            if (this.lastTabStop !== null) {
                switch (this.lastTabStop.tagName) {
                    case "IC-NAVIGATION-BUTTON":
                    case NAV_ITEM_TAG:
                    case NAV_GROUP_TAG:
                        focusEl = this.lastTabStop;
                        focusEl.focus();
                        break;
                    case "A":
                        this.lastTabStop.focus();
                        break;
                }
            }
        };
    }
    componentWillLoad() {
        this.navBarEl = document.querySelector("ic-top-navigation");
        this.navigationEls = getSlotContent(this.el, "navigation");
        if (this.navigationEls) {
            this.hasNavigation = true;
            const lastEl = this.navigationEls[this.navigationEls.length - 1];
            if (lastEl.tagName === NAV_ITEM_TAG) {
                this.navItemAboveButtons = true;
            }
            else if (lastEl.tagName === NAV_GROUP_TAG) {
                lastEl.addEventListener("navigationGroupExpanded", ((event) => {
                    this.setLastTabStop(event.detail.expanded);
                }));
            }
            const firstEl = this.navigationEls[0];
            if (firstEl.tagName === NAV_GROUP_TAG) {
                this.navGroupFirst = true;
            }
        }
        const buttonContent = getSlotContent(this.el, "buttons");
        if (buttonContent !== null) {
            this.hasButtons = true;
            this.lastTabStop = buttonContent[buttonContent.length - 1];
        }
        else {
            if (this.hasNavigation && this.navigationEls) {
                this.setLastTabStop(false);
            }
        }
    }
    componentDidLoad() {
        this.focusCloseButton();
    }
    componentWillRender() {
        this.hasNavigation = isSlotUsed(this.el, "navigation");
        this.hasButtons = isSlotUsed(this.el, "buttons");
    }
    navItemClickHandler() {
        this.closeMenu();
    }
    handleKeyDown(ev) {
        if (ev.key === "Tab") {
            if (ev.shiftKey) {
                if (document.activeElement === this.navBarEl) {
                    ev.preventDefault();
                    this.focusLastTabStop();
                }
            }
            else if (document.activeElement === this.lastTabStop ||
                this.lastTabStop === null) {
                ev.preventDefault();
                this.focusCloseButton();
            }
        }
        else if (ev.key === "Escape") {
            this.closeMenu();
        }
    }
    render() {
        return (h(Host, { key: '238491dcf801f29d30b1da0e65546592557fde24', class: { [`ic-theme-${this.theme}`]: this.theme !== "inherit" } }, h("div", { key: '1f4c1f5653cf725ea520300c56f7769716ed5c2a', class: "popout-modal", onClick: this.closeMenu }), h("div", { key: '7b1ff84083af3b3ceb6e309844c99d7e3a0ae350', class: "popout-menu", role: "dialog", "aria-modal": "true", "aria-label": `${this.hasNavigation ? "Navigation" : "App"} menu` }, h("span", { key: '3fbc25efa5a16c9f091ab455379e2c94ae5f35ca', "aria-hidden": "true", id: "navigation-landmark-text", class: "navigation-landmark-text" }, "Main navigation"), h("nav", { key: '2847e0434b96df094d4d14dc39aaa65d9b504435', "aria-labelledby": "navigation-landmark-text", "aria-hidden": this.hasNavigation ? "false" : "true" }, h("div", { key: 'a9543c0611d2c8dd1427500b1cd4cbf2de448b7b', class: {
                ["menu-close-button-container"]: true,
                ["nav-group-first"]: this.navGroupFirst,
            } }, h("ic-button", { key: 'c6116c335e9c6c29bde6485421b3d72456e4c485', ref: (el) => (this.closeButton = el), id: "menu-close-button", class: "menu-close-button", variant: "icon", size: "large", "aria-label": `Close ${this.hasNavigation ? "navigation" : "app"} menu`, onClick: this.closeMenu }, h("svg", { key: 'f224bd0fbc219bb6ae337399e6f08c3187d32fb7', width: "14", height: "14", viewBox: "0 0 14 14", fill: "none", xmlns: "http://www.w3.org/2000/svg" }, h("path", { key: 'a4419dfcec4df358e35bb7c9b623e5a720b89a3e', d: "M14 1.41L12.59 0L7 5.59L1.41 0L0 1.41L5.59 7L0 12.59L1.41 14L7 8.41L12.59 14L14 12.59L8.41 7L14 1.41Z" })))), this.hasNavigation && h("slot", { key: '29d722a813544e8e82a07e2642a7014b32673dda', name: "navigation" })), this.hasButtons && (h("div", { key: '96ee54e19b08c60e1de050dc06367009bb15484f', class: {
                ["menu-buttons-container"]: true,
                ["menu-buttons-container-nav-item-above"]: this.navItemAboveButtons,
            } }, h("slot", { key: '851897a3d08d4a74078379b16fb66f74392380dd', name: "buttons" }))), (this.status !== "" || this.version !== "") && (h("div", { key: 'faa0f531a4f2232c343b7197a798f7b79bfaaa17', class: {
                ["menu-status-version-container"]: true,
                ["status-version-no-buttons"]: !this.hasButtons,
            } }, this.status !== "" && (h("div", { key: '43000a7655c49bdd7c15beaaef8f371f20c59049', class: "menu-status" }, h("ic-typography", { key: 'f92edc3ead11de1eb052835e0fef11ea26f70e91', variant: "label-uppercase", "aria-label": "app tag", class: "menu-status-text" }, this.status))), this.version !== "" && (h("div", { key: '84b3193b76f979b9dfd967fe549eb996dedf3631', class: "menu-version" }, h("ic-typography", { key: 'f3ea4120a05fc6707ff54ce634aa6798d7dbade3', variant: "label", class: "menu-version-text", "aria-label": "app version" }, this.version))))))));
    }
    get el() { return this; }
    static get style() { return IcNavigationMenuStyle0; }
}, [1, "ic-navigation-menu", {
        "status": [1],
        "theme": [1],
        "version": [1]
    }, [[0, "navItemClicked", "navItemClickHandler"], [4, "keydown", "handleKeyDown"]]]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["ic-navigation-menu", "ic-button", "ic-loading-indicator", "ic-tooltip", "ic-typography"];
    components.forEach(tagName => { switch (tagName) {
        case "ic-navigation-menu":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, NavigationMenu);
            }
            break;
        case "ic-button":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "ic-loading-indicator":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "ic-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "ic-typography":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}

export { NavigationMenu as N, defineCustomElement as d };

//# sourceMappingURL=ic-navigation-menu2.js.map